@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
 import string
-from datetime import datetime, time
+from datetime import datetime,timedelta
 
 from numpy import long
+from dataclasses import dataclass, field
 from pymssql import InternalError
 from sqlalchemy import Time, create_engine, exc, Table, MetaData, Column, Integer, String, DateTime, Boolean
 from sqlalchemy.orm import sessionmaker, mapper
@@ -80,7 +81,7 @@ class CAPStorage(CAPStorageBase):
                 message_published.Name = routing_key
                 message_published.Content = message
                 message_published.Added = str(datetime.now())
-                message_published.ExpiresAt = str(datetime.now()+datetime.timedelta(days=1))
+                message_published.ExpiresAt = str(datetime.now()+timedelta(days=1))
                 message_published.StatusName = status
                 session.add(message_published)
 
